@@ -405,7 +405,7 @@ class Component(Chemical):
         if measured_as:
             if measured_as == 'COD':
                 self._MW = molecular_weight({'O':2})
-            elif measured_as in self.atoms:
+            elif measured_as in self.atoms or 'i_'+measured_as in _num_component_properties:
                 self._MW = molecular_weight({measured_as:1})
             else:
                 raise AttributeError(f"Component {self.ID} must be measured as "
@@ -422,7 +422,7 @@ class Component(Chemical):
             denom = self._i_mass
         elif new == 'COD':
             denom = self._i_COD
-        elif new in self.atoms:
+        elif new in self.atoms or 'i_'+new in _num_component_properties:
             try: denom = getattr(self, '_i_'+new)
             except AttributeError:
                 denom = get_mass_frac(self.atoms)[new] * self._i_mass
@@ -476,7 +476,7 @@ class Component(Chemical):
         return self._i_COD or 0.
     @i_COD.setter
     def i_COD(self, i):
-        if i: self._i_COD = check_return_property('i_COD', i)
+        if i != None: self._i_COD = check_return_property('i_COD', i)
         else:
             if self.organic or self.formula in ('H2', 'O2', 'N2', 'NO2-', 'NO3-'):
                 if self.measured_as == 'COD': self._i_COD = 1.
@@ -512,6 +512,14 @@ class Component(Chemical):
         self._i_NOD = check_return_property('i_NOD', i)
 
 
+    def __str__(self):
+        return self._ID
+
+
+    def __repr__(self):
+        return f"Component('{self}')"
+
+
     def show(self, chemical_info=False):
         '''
         Show component properties.
@@ -558,6 +566,7 @@ class Component(Chemical):
 
     _ipython_display_ = show
 
+
     def get_missing_properties(self, properties=None):
         '''Return a list of all missing thermodynamic properties.'''
         missing = []
@@ -570,23 +579,32 @@ class Component(Chemical):
                 missing.append(i)
         return missing
 
+
     def copy(self, new_ID, **data):
         '''
         Return a new :class:`Component` object with the same settings with
         alternative data set by kwargs.
         '''
         new = self.__class__.__new__(cls=self.__class__, ID=new_ID)
-        new = copy_attr(new, self, skip=('_ID', '_CAS', '_N_solutes'))
+        new = copy_attr(new, self, skip=('_ID', '_CAS', '_N_solutes', '_locked_state'))
         new._ID = new_ID
-        new._locked_state = self._locked_state
-        new._init_energies(new.Cn, new.Hvap, new.Psat, new.Hfus, new.Sfus, new.Tm,
-                           new.Tb, new.eos, new.eos_1atm, new.phase_ref)
+
+        phase = data.get('phase') or self._locked_state
+        new._locked_state = phase
+
+        new._init_energies(new.Cn, new.Hvap, new.Psat, new.Hfus, new.Sfus,
+                           new.Tm, new.Tb, new.eos, new.phase_ref)
         new._label_handles()
-        for i,j in data.items(): setattr(new, i , j)
+
+        for i,j in data.items():
+            if i == 'phase':
+                continue
+            setattr(new, i , j)
         return new
 
     __copy__ = copy
 
+
     @classmethod
     def from_chemical(cls, ID, chemical=None, phase=None, measured_as=None,
                       i_C=None, i_N=None, i_P=None, i_K=None, i_Mg=None, i_Ca=None,
@@ -610,8 +628,8 @@ class Component(Chemical):
 
         if phase: new._locked_state = phase
 
-        new._init_energies(new.Cn, new.Hvap, new.Psat, new.Hfus, new.Sfus, new.Tm,
-                           new.Tb, new.eos, new.eos_1atm, new.phase_ref)
+        new._init_energies(new.Cn, new.Hvap, new.Psat, new.Hfus, new.Sfus,
+                           new.Tm, new.Tb, new.eos, new.phase_ref)
         new._label_handles()
         new._measured_as = measured_as
         new.i_mass = i_mass
