@@ -15,28 +15,24 @@ for license details.
 
 # %%
 
-import math
+import sys, math
 import numpy as np
 import pandas as pd
 from collections.abc import Iterable
 from warnings import warn
-from . import ImpactItem, Stream, SanStream, SanUnit
+from . import ImpactIndicator, ImpactItem, Stream, SanStream, SanUnit
 from .utils import (
     auom,
     format_number as f_num
     )
 
-isinstance = isinstance
-iter = iter
-callable = callable
-
 __all__ = ('LCA',)
 
 
 class LCA:
     '''
     For life cycle assessment (LCA) of a System.
-    
+
     Parameters
     ----------
     system : :class:`biosteam.System`
@@ -47,15 +43,17 @@ class LCA:
         Unit of lifetime.
     uptime_ratio : float
         Fraction of time that the system is operating.
+    indicators : iterable
+        `ImpactIndicator` objects or their IDs/aliases
     item_quantities : kwargs, :class:`ImpactItem` or str = float/callable or (float/callable, unit)
         Other :class:`ImpactItem` objects (e.g., electricity) and their quantities.
         Note that callable functions are used so that quantity of items can be updated.
-    
+
 
     Examples
     --------
     A system should be constructed prior to LCA, here we import a pre-constructed one.
-    
+
     >>> import qsdsan as qs
     >>> from qsdsan.utils import load_example_cmps, load_example_sys
     >>> cmps = load_example_cmps()
@@ -85,25 +83,25 @@ class LCA:
         phase: 'l', T: 350 K, P: 101325 Pa
         flow (kmol/hr): H2O   88.8
                         NaCl  0.684
-    
+
     And we also need to specify the impact indicators that we are interested in.
-    
+
     >>> GWP = qs.ImpactIndicator('GlobalWarming', alias='GWP', unit='kg CO2-eq')
     >>> FEC = qs.ImpactIndicator('FossilEnergyConsumption', alias='FEC', unit='MJ')
-    
+
     There are four different types of impacts in `QSDsan`:
     construction, transportation, stream, and others.
-    
+
     Note that it is best to add the impact items when developing the unit module,
     (i.e., typically in the `_design` function, but can also in `_run`  or `_cost`)
     but for illustrative purpose, we add it after the system is constructed.
-    
+
     Construction is mainly used for impacts that only occur once per lifetime
     of the equipment or the unit.
-    
+
     For example, assume we want to consider the amount of stainless steel
     and concrete used in constructing the MixTank M1.
-    
+
     >>> # Make the impact item, numbers are made up
     >>> SS = qs.ImpactItem('SS', functional_unit='kg', GWP=3, FEC=50)
     >>> Concrete = qs.ImpactItem('Concrete', functional_unit='kg', GWP=4, FEC=30)
@@ -115,13 +113,13 @@ class LCA:
     >>> M1 = flowsheet.unit.M1
     >>> # Add the construction activity
     >>> M1.construction = (SS_constr_M1, Concrete_constr_M1)
-    
+
     Transportation activity can be added in a similar manner, assuming that
     stainless steel and concrete are delivered by truck from 500 km away.
 
     The interval set below is assuming a system lifetime of 10 year
     and this delivery is only needed once for the entire lifetime.
-    
+
     >>> lifetime = 10
     >>> Trucking = qs.ImpactItem('Trucking', functional_unit='kg*km',
     ...                          GWP=0.5, FEC=1.5)
@@ -134,8 +132,8 @@ class LCA:
     We can als consider the impacts associated with chemicals and emissions.
     For example, assume the acquisition of methanol, ethanol and disposal of
     the waste brine all have impacts, but the generated alcohols can be treated
-    as a product therefore have credits with 
-    
+    as a product therefore have credits with
+
     >>> # Retrieve streams
     >>> methanol = flowsheet.stream.methanol
     >>> ethanol = flowsheet.stream.ethanol
@@ -146,12 +144,12 @@ class LCA:
     >>> ethanol_item = qs.StreamImpactItem(linked_stream=ethanol, GWP=2.1, FEC=25)
     >>> alcohols_item = qs.StreamImpactItem(linked_stream=alcohols, GWP=-0.2, FEC=-5)
     >>> brine_item = qs.StreamImpactItem(linked_stream=methanol, GWP=2, FEC=3)
-    
+
     Finally, there might be other impacts we want to include in the LCA,
     for example, the electricity needed to operate the system.
-    
+
     We can use add those additional items when creating the `LCA` object.
-    
+
     >>> # Get the electricity usage of the system throughout the lifetime,
     >>> # note that the default power utility unit is hr
     >>> total_power = sum((i.rate for i in sys.power_utilities))*24*365*lifetime
@@ -161,56 +159,58 @@ class LCA:
     >>> lca = qs.LCA(system=sys, lifetime=10, e_item=total_power)
 
     Now we can look at the total impacts associate with this system.
-    
+
     >>> lca.show() # doctest: +SKIP
     LCA: sys (lifetime 10 yr)
     Impacts:
-                                  Construction  Transportation  WasteStream   Others    Total
+                                  Construction  Transportation       Stream   Others    Total
     FossilEnergyConsumption (MJ)       6.5e+03        1.12e+05      1.4e+07 1.95e+06 1.61e+07
     GlobalWarming (kg CO2-eq)              500        3.75e+04     4.82e+06 8.94e+04 4.95e+06
     >>> # Retrieve impacts associated with a specific indicator
-    >>> lca.total_impacts['GlobalWarming']
-    4945363.316130896
-    
+
     Or breakdowns of the different category
-    
+
     >>> lca.total_impacts['GlobalWarming'] # doctest: +ELLIPSIS
-    4945363.3...
+    4944207...
     >>> lca.get_impact_table('Construction') # doctest: +SKIP
 
     See Also
     --------
     `SanUnit and System <https://qsdsan.readthedocs.io/en/latest/tutorials/SanUnit_and_System.html>`_
-    
+
     `TEA and LCA <https://qsdsan.readthedocs.io/en/latest/tutorials/TEA_and_LCA.html>`_
     '''
-    
+
     __slots__ = ('_system',  '_lifetime', '_uptime_ratio',
                  '_construction_units', '_transportation_units',
-                 '_lca_streams', '_impact_indicators',
+                 '_lca_streams', '_indicators',
                  '_other_items', '_other_items_f')
-    
-    
-    def __init__(self, system, lifetime, lifetime_unit='yr', uptime_ratio=1,
-                 **item_quantities):
+
+
+    def __init__(self, system, lifetime, lifetime_unit='yr',
+                 indicators=(), uptime_ratio=1, **item_quantities):
         system.simulate()
         self._construction_units = set()
         self._transportation_units = set()
         self._lca_streams = set()
         self._update_system(system)
         self._update_lifetime(lifetime, lifetime_unit)
+        self.indicators = indicators
         self.uptime_ratio = uptime_ratio
         self._other_items = {}
         self._other_items_f = {}
         for item, val in item_quantities.items():
             try:
                 f_quantity, unit = val # unit provided for the quantity
-            except:
-                f_quantity = val
-                unit = ''
+            except Exception as e:
+                if 'unpack' in str(sys.exc_info()[1]):
+                    f_quantity = val
+                    unit = ''
+                else:
+                    raise e
             self.add_other_item(item, f_quantity, unit)
-            
-    
+
+
     def _update_system(self, system):
         for u in system.units:
             if not isinstance (u, SanUnit):
@@ -224,9 +224,9 @@ class LCA:
         self._transportation_units = sorted(self._transportation_units,
                                             key=lambda u: u.ID)
         for s in (i for i in system.feeds+system.products):
-            if not hasattr(s, 'impact_item'):
+            if not hasattr(s, 'stream_impact_item'):
                 continue
-            if s.impact_item:
+            if s.stream_impact_item:
                 self._lca_streams.add(s)
         self._lca_streams = sorted(self._lca_streams, key=lambda s: s.ID)
         self._system = system
@@ -239,7 +239,7 @@ class LCA:
             converted = auom(unit).convert(int(lifetime), 'yr')
             self._lifetime = converted
 
-    
+
     def add_other_item(self, item, f_quantity, unit=''):
         '''Add other :class:`ImpactItem` in LCA.'''
         if isinstance(item, str):
@@ -258,15 +258,15 @@ class LCA:
                                  f'item functional unit {fu} is not supported.')
         self._other_items_f[item.ID] = {'item':item, 'f_quantity':f, 'unit':unit}
         self.other_items[item.ID] = {'item':item, 'quantity':quantity}
-        
-    
+
+
     def refresh_other_items(self):
         '''Refresh quantities of other items using the given functions.'''
         for item_ID, record in self._other_items_f.items():
             item, f_quantity, unit = record.values()
             self.other_items[item_ID]['quantity'] = f_quantity()
-        
-        
+
+
     def __repr__(self):
         return f'<LCA: {self.system}>'
 
@@ -283,43 +283,49 @@ class LCA:
             df = pd.DataFrame({
                 'Construction': tuple(self.total_construction_impacts.values()),
                 'Transportation': tuple(self.total_transportation_impacts.values()),
-                'WasteStream': tuple(self.total_stream_impacts.values()),
+                'Stream': tuple(self.total_stream_impacts.values()),
                 'Others': tuple(self.total_other_impacts.values()),
                 'Total': tuple(self.total_impacts.values())
                 },
                 index=index)
             # print(' '*9+df.to_string().replace('\n', '\n'+' '*9))
             print(df.to_string())
-    
+
     _ipython_display_ = show
-    
-    
+
+
     def get_construction_impacts(self, units, time=None, time_unit='hr'):
         '''
         Return all construction-related impacts for the given unit,
         normalized to a certain time frame.
         '''
-        if not isinstance(units, Iterable):
+        if not isinstance(units, Iterable) or isinstance(units, str):
             units = (units,)
-        if not time:
-            ratio = 1
+        if time is None:
+            time = self.lifetime_hr
         else:
-            converted = auom(time_unit).convert(float(time), 'hr')
-            ratio = converted/self.lifetime_hr
+            time = auom(time_unit).convert(float(time), 'hr')
         impacts = dict.fromkeys((i.ID for i in self.indicators), 0.)
         for i in units:
             if not isinstance(i, SanUnit):
                 continue
             for j in i.construction:
                 impact = j.impacts
-                if j.lifetime is not None:
-                    factor = math.ceil(time/j.lifetime)
-                else:
-                    factor = 1.
+                if j.lifetime is not None: # this equipment has a lifetime
+                    constr_lifetime = auom('yr').convert(j.lifetime, 'hr')
+                    ratio = math.ceil(time/constr_lifetime)
+                else: # equipment doesn't have a lifetime
+                    if i.lifetime and not isinstance(i.lifetime, dict): # unit has a uniform lifetime
+                        constr_lifetime = auom('yr').convert(i.lifetime, 'hr')
+                        ratio = math.ceil(time/constr_lifetime)
+                    else: # no lifetime, assume just need one
+                        ratio = 1.
                 for m, n in impact.items():
-                    impacts[m] += n*ratio*factor
+                    if m not in impacts.keys():
+                        continue
+                    impacts[m] += n*ratio
         return impacts
-    
+
     def get_transportation_impacts(self, units, time=None, time_unit='hr'):
         '''
         Return all transportation-related impacts for the given unit,
@@ -338,22 +344,24 @@ class LCA:
             for j in i.transportation:
                 impact = j.impacts
                 for m, n in impact.items():
+                    if m not in impacts.keys():
+                        continue
                     impacts[m] += n*time/j.interval
         return impacts
-    
-    
+
+
     def get_stream_impacts(self, stream_items=None, exclude=None,
                            kind='all', time=None, time_unit='hr'):
         '''
         Return all stream-related impacts for the given streams,
         normalized to a certain time frame.
         '''
+        if stream_items == None:
+            stream_items = self.stream_inventory
         if not isinstance(stream_items, Iterable):
             stream_items = (stream_items,)
         if not isinstance(exclude, Iterable):
             exclude = (exclude,)
-        if stream_items == None:
-            stream_items = self.stream_inventory
         impacts = dict.fromkeys((i.ID for i in self.indicators), 0.)
         if not time:
             time = self.lifetime_hr
@@ -370,7 +378,9 @@ class LCA:
                 else: continue
             else:
                 ws = j.linked_stream
+
             if ws in exclude: continue
+
             for m, n in j.CFs.items():
                 if kind == 'all':
                     pass
@@ -381,9 +391,11 @@ class LCA:
                 else:
                     raise ValueError('kind can only be "all", "direct_emission", or "offset", '
                                      f'not {kind}.')
+                if m not in impacts.keys():
+                    continue
                 impacts[m] += n*time*ws.F_mass
         return impacts
-    
+
     def get_other_impacts(self):
         '''
         Return all additional impacts from "other" :class:`ImpactItems` objects,
@@ -391,13 +403,15 @@ class LCA:
         '''
         self.refresh_other_items()
         impacts = dict.fromkeys((i.ID for i in self.indicators), 0.)
-        other_dct = self.other_items         
+        other_dct = self.other_items
         for i in other_dct.keys():
             item = ImpactItem.get_item(i)
             for m, n in item.CFs.items():
+                if m not in impacts.keys():
+                    continue
                 impacts[m] += n*other_dct[i]['quantity']
         return impacts
-    
+
     def get_total_impacts(self, exclude=None, time=None, time_unit='hr'):
         '''Return total impacts, normalized to a certain time frame.'''
         impacts = dict.fromkeys((i.ID for i in self.indicators), 0.)
@@ -408,13 +422,15 @@ class LCA:
                   ws_impacts,
                   self.total_other_impacts):
             for m, n in i.items():
+                if m not in impacts.keys():
+                    continue
                 impacts[m] += n
         return impacts
 
     def get_allocated_impacts(self, streams=(), allocate_by='mass'):
         '''
         Allocate total impacts to one or multiple streams.
-        
+
         Parameters
         ----------
         streams : :class:`WasteStream` or iterable
@@ -427,12 +443,12 @@ class LCA:
             will allocate impacts according to the iterable.
             If provided as a function,  will call the function to generate an
             iterable to allocate the impacts accordingly.
-        
+
         .. note::
-            
+
             Energy of the stream will be calcuated as the sum of HHVs of all components
             in the stream.
-        
+
         '''
         if not isinstance(streams, Iterable):
             streams = (streams,)
@@ -467,8 +483,8 @@ class LCA:
             allocated[s.ID] = dict.fromkeys(impact_dct.keys(),
                                             (ratios[n]*impact_vals).sum())
         return allocated
-        
-    
+
+
     def get_unit_impacts(self, units, time=None, time_unit='hr',
                           exclude=None):
         '''Return total impacts with certain units, normalized to a certain time frame. '''
@@ -476,7 +492,7 @@ class LCA:
             units = (units,)
         constr = self.get_construction_impacts(units, time, time_unit)
         trans = self.get_transportation_impacts(units, time, time_unit)
-        stream_items = set(i for i in 
+        stream_items = set(i for i in
                        sum((tuple(unit.ins+unit.outs) for unit in units), ())
                        if i.impact_item)
 
@@ -487,22 +503,25 @@ class LCA:
         for m in tot.keys():
             tot[m] += trans[m] + s[m] + other[m]
         return tot
-    
-    def _append_cat_sum(self, cat_table, cat, tot):
+
+    def _append_cat_sum(self, cat_table, cat, tot, time_ratio=1):
         num = len(cat_table)
-        cat_table.loc[num] = ''
+        cat_table.loc[num] = '' # initiate a blank spot for value to be added later
+
         for i in self.indicators:
-            cat_table[f'{i.ID} [{i.unit}]'][num] = tot[i.ID]
+            cat_table[f'{i.ID} [{i.unit}]'][num] = tot[i.ID] * time_ratio
             cat_table[f'Category {i.ID} Ratio'][num] = 1
-        if cat in ('construction', 'transportation'):        
+
+        if cat in ('construction', 'transportation'):
             cat_table.rename(index={num: ('Sum', 'All')}, inplace=True)
             cat_table.index = \
                 pd.MultiIndex.from_tuples(cat_table.index,
                                           names=[cat.capitalize(), 'SanUnit'])
         else:
             cat_table.rename(index={num: 'Sum'}, inplace=True)
+
         return cat_table
-    
+
     def get_impact_table(self, category, time=None, time_unit='hr'):
         '''
         Return a :class:`pandas.DataFrame` table for the given impact category,
@@ -512,10 +531,11 @@ class LCA:
             time = self.lifetime_hr
         else:
             time = auom(time_unit).convert(float(time), 'hr')
-        
+
         cat = category.lower()
         tot = getattr(self, f'total_{cat}_impacts')
-        
+        time_ratio = time/self.lifetime_hr
+
         if cat in ('construction', 'other'):
             time = time/self.lifetime_hr
 
@@ -536,10 +556,11 @@ class LCA:
                     continue
                 for i in getattr(su, cat):
                     item_dct[i.item.ID]['SanUnit'].append(su.ID)
-                    item_dct[i.item.ID]['Quantity'].append(i.quantity*time)
                     if cat == 'transportation':
-                        item_dct[i.item.ID]['Quantity'][-1] /= i.interval
-                        
+                        item_dct[i.item.ID]['Quantity'].append(i.quantity*time/i.interval)
+                    else: # construction
+                        item_dct[i.item.ID]['Quantity'].append(i.quantity*time_ratio)
+
             dfs = []
             for item in items:
                 dct = item_dct[item.ID]
@@ -550,7 +571,7 @@ class LCA:
                 for i in self.indicators:
                     if i.ID in item.CFs:
                         dct[f'{i.ID} [{i.unit}]'] = impact = dct['Quantity']*item.CFs[i.ID]
-                        dct[f'Category {i.ID} Ratio'] = impact/tot[i.ID]
+                        dct[f'Category {i.ID} Ratio'] = impact/(tot[i.ID]*time_ratio)
                     else:
                         dct[f'{i.ID} [{i.unit}]'] = dct[f'Category {i.ID} Ratio'] = 0
                 df = pd.DataFrame.from_dict(dct)
@@ -562,11 +583,11 @@ class LCA:
                 dfs.append(df)
 
             table = pd.concat(dfs)
-            return self._append_cat_sum(table, cat, tot)
-        
+            return self._append_cat_sum(table, cat, tot, time_ratio)
+
         ind_head = sum(([f'{i.ID} [{i.unit}]',
                          f'Category {i.ID} Ratio'] for i in self.indicators), [])
-        
+
         if cat in ('stream', 'streams'):
             headings = ['Stream', 'Mass [kg]', *ind_head]
             item_dct = dict.fromkeys(headings)
@@ -581,13 +602,13 @@ class LCA:
                     if ind.ID in ws_item.CFs.keys():
                         impact = ws_item.CFs[ind.ID]*mass
                         item_dct[f'{ind.ID} [{ind.unit}]'].append(impact)
-                        item_dct[f'Category {ind.ID} Ratio'].append(impact/tot[ind.ID])
+                        item_dct[f'Category {ind.ID} Ratio'].append(impact/(tot[ind.ID]*time_ratio))
                     else:
                         item_dct[f'{ind.ID} [{ind.unit}]'].append(0)
                         item_dct[f'Category {ind.ID} Ratio'].append(0)
             table = pd.DataFrame.from_dict(item_dct)
             table.set_index(['Stream'], inplace=True)
-            return self._append_cat_sum(table, cat, tot)
+            return self._append_cat_sum(table, cat, tot, time_ratio)
 
         elif cat == 'other':
             headings = ['Other', 'Quantity', *ind_head]
@@ -603,15 +624,15 @@ class LCA:
                     if ind.ID in other.CFs.keys():
                         impact = other.CFs[ind.ID]*quantity
                         item_dct[f'{ind.ID} [{ind.unit}]'].append(impact)
-                        item_dct[f'Category {ind.ID} Ratio'].append(impact/tot[ind.ID])
+                        item_dct[f'Category {ind.ID} Ratio'].append(impact/(tot[ind.ID]*time_ratio))
                     else:
                         item_dct[f'{ind.ID} [{ind.unit}]'].append(0)
                         item_dct[f'Category {ind.ID} Ratio'].append(0)
-            
+
             table = pd.DataFrame.from_dict(item_dct)
             table.set_index(['Other'], inplace=True)
-            return self._append_cat_sum(table, cat, tot)
-        
+            return self._append_cat_sum(table, cat, tot, time_ratio)
+
         raise ValueError(
             'category can only be "Construction", "Transportation", "Stream", or "Other", ' \
             f'not "{category}".')
@@ -639,7 +660,7 @@ class LCA:
     @system.setter
     def system(self, i):
         self._update_system(i)
-    
+
     @property
     def lifetime(self):
         '''[int] Lifetime of the system, [yr].'''
@@ -647,12 +668,12 @@ class LCA:
     @lifetime.setter
     def lifetime(self, lifetime, unit='yr'):
         self._update_lifetime(lifetime, unit)
-        
+
     @property
     def lifetime_hr(self):
         '''[float] Lifetime of the system in hours, [hr].'''
         return self._lifetime*365*24*self.uptime_ratio
-    
+
     @property
     def uptime_ratio(self):
         '''[float] Fraction of time that the system is operating.'''
@@ -663,10 +684,19 @@ class LCA:
             self._uptime_ratio = float(i)
         else:
             raise ValueError('uptime_ratio must be in [0,1].')
-    
+
     @property
     def indicators(self):
-        '''[set] All impact indicators associated with this LCA.'''
+        '''
+        [list] All impact indicators associated with this LCA object.
+        If not `ImpactIndicator` has been added, then will be defaulted to
+        sum of the `ImpactIndicator` objects added to the system associated
+        with this LCA (e.g., associated with construction, streams, etc.
+
+        '''
+        if self._indicators:
+            return self._indicators
+
         if not self.construction_inventory:
             constr = set()
         else:
@@ -690,53 +720,65 @@ class LCA:
         tot = constr.union(trans, ws, other)
         if len(tot) == 0:
             warn('No `ImpactIndicator` has been added.')
-        return tot
-    
+        return list(tot)
+    @indicators.setter
+    def indicators(self, i):
+        if not (isinstance(i, Iterable) and not isinstance(i, str)):
+            i = (i,)
+        inds = []
+        for ind in i:
+            if isinstance(ind, str):
+                ind = ImpactIndicator.get_indicator(ind)
+            if not isinstance(ind, ImpactIndicator):
+                raise TypeError(f'{ind} is not an `ImpactIndicator` or ID/alias of an `ImpactIndicator`.')
+            inds.append(ind)
+        self._indicators = inds
+
     @property
     def construction_units(self):
         '''[set] All units in the linked system with constrution activity.'''
         return self._construction_units
-    
+
     @property
     def construction_inventory(self):
         '''[tuple] All construction activities.'''
         return sum((i.construction for i in self.construction_units), ())
-    
+
     @property
     def total_construction_impacts(self):
         '''[dict] Total impacts associated with construction activities.'''
         return self.get_construction_impacts(self.construction_units)
-    
+
     @property
     def transportation_units(self):
         '''[set] All units in the linked system with transportation activity.'''
         return self._transportation_units
-    
+
     @property
     def transportation_inventory(self):
         '''[tuple] All transportation activities.'''
         return sum((i.transportation for i in self.transportation_units), ())
-    
+
     @property
     def total_transportation_impacts(self):
         '''[dict] Total impacts associated with transportation activities.'''
         return self.get_transportation_impacts(self.transportation_units)
-    
+
     @property
     def lca_streams(self):
         '''[set] All streams in the linked system with impacts.'''
         return self._lca_streams
-    
+
     @property
     def stream_inventory(self):
         '''[tuple] All chemical inputs, fugitive gases, waste emissions, and products.'''
-        return tuple(i.impact_item for i in self.lca_streams)
-    
+        return tuple(i.stream_impact_item for i in self.lca_streams)
+
     @property
     def total_stream_impacts(self):
         '''[dict] Total impacts associated with `WasteStreams` (e.g., chemicals, emissions).'''
         return self.get_stream_impacts(stream_items=self.stream_inventory)
-        
+
     @property
     def other_items (self):
         '''[dict] Other impact items (e.g., electricity) and their quantities.'''
@@ -744,19 +786,13 @@ class LCA:
     @other_items.setter
     def other_items(self, item, f_quantity, unit=''):
         self.add_other_item(item, f_quantity, unit)
-        
+
     @property
     def total_other_impacts(self):
         '''[dict] Total impacts associated with other ImpactItems (e.g., electricity).'''
         return self.get_other_impacts()
-    
+
     @property
     def total_impacts(self):
         '''[dict] Total impacts of the entire system (construction, transportation, and wastestream).'''
-        return self.get_total_impacts()
-
-
-
-
-
-
+        return self.get_total_impacts()
\ No newline at end of file
