@@ -434,6 +434,7 @@ class Processes():
             process = Process(ID, stoichio, 
                               ref_component=ref, 
                               rate_equation=rate_eq,
+                              components=components,
                               conserved_for=conserved_for,
                               parameters=parameters)
             new.append(process)
@@ -602,12 +603,18 @@ class CompiledProcesses(Processes):
     def __len__(self):
         return self.size
     
+    def __iter__(self):
+        return iter(self.tuple)
+        
     def copy(self):
         '''Return a copy.'''
-        copy = Processes(self)
+        copy = Processes(self.tuple)
         copy.compile()
         return copy    
     
     def set_parameters(self, **parameters):
         '''Set values to stoichiometric and/or kinetic parameters.'''
-        self._parameters.update(parameters)
\ No newline at end of file
+        self._parameters.update(parameters)
+    
+    def __repr__(self):
+        return f"{type(self).__name__}([{', '.join(self.IDs)}])"
\ No newline at end of file
