@@ -30,6 +30,7 @@ from thermosteam import settings
 from . import Components, Stream, MultiStream, SanStream, MissingSanStream, \
     set_thermo
 from .utils import auom, copy_attr
+from warnings import warn
 
 __all__ = ('WasteStream', 'MissingWasteStream')
 
@@ -42,7 +43,7 @@ _common_composite_vars = ('_COD', '_BOD', '_uBOD', '_TC', '_TOC', '_TN',
                           '_dry_mass', '_charge', '_ThOD', '_cnBOD')
 
 _ws_specific_slots = (*_common_composite_vars,
-                      '_pH', '_SAlk', '_ratios', '_impact_item')
+                      '_pH', '_SAlk', '_ratios', '_stream_impact_item')
 
 _specific_groups = {'S_VFA': ('S_Ac', 'S_Prop'),
                     'X_Stor': ('X_OHO_PHA', 'X_GAO_PHA', 'X_PAO_PHA',
@@ -67,8 +68,18 @@ vol_unit = auom('L/hr')
 conc_unit = auom('mg/L')
 
 
-#%% functions for calibrations of N, P contents and BOD:COD ratio of certain components
+# %%
 
+# =============================================================================
+# Util functions
+# =============================================================================
+
+_load_components = settings.get_default_chemicals
+
+def to_float(stream, slot):
+    return 0. if getattr(stream, slot) is None else float(getattr(stream, slot))
+
+# functions for calibrations of N, P contents and BOD:COD ratio of certain components
 def _calib_SF_iN(components, concentrations, STKN):
     cmp_c = np.asarray([v for v in concentrations.values()])
     SN = (cmp_c * components.i_N * (components.s + components.c)).sum()
@@ -115,8 +126,6 @@ def _calib_XBsub_fBODCOD(components, concentrations, substrate_IDs, BOD):
 # Define the WasteStream class
 # =============================================================================
 
-_load_components = settings.get_default_chemicals
-
 class WasteStream(SanStream):
     '''
     A subclass of :class:`~.SanStream` with additional attributes and methods
@@ -169,7 +178,7 @@ class WasteStream(SanStream):
         TO BE IMPLEMENTED
     ratios : float
         TO BE IMPLEMENTED
-    impact_item : :class:`StreamImpactItem`
+    stream_impact_item : :class:`StreamImpactItem`
         The :class:`StreamImpactItem` this stream is linked to.
     component_flows : kwargs
         Component flow data.
@@ -194,11 +203,11 @@ class WasteStream(SanStream):
                  ThOD=None, cnBOD=None,
                  TC=None, TOC=None, TN=None, TKN=None, TP=None, TK=None,
                  TMg=None, TCa=None, dry_mass=None, charge=None, ratios=None,
-                 impact_item=None, **component_flows):
+                 stream_impact_item=None, **component_flows):
 
         SanStream.__init__(self=self, ID=ID, flow=flow, phase=phase, T=T, P=P,
                            units=units, price=price, thermo=thermo,
-                           impact_item=impact_item, **component_flows)
+                           stream_impact_item=stream_impact_item, **component_flows)
 
         self._init_ws(pH, SAlk, COD, BOD, uBOD, TC, TOC, TN, TKN,
                       TP, TK, TMg, TCa, ThOD, cnBOD, dry_mass, charge, ratios)
@@ -265,6 +274,8 @@ class WasteStream(SanStream):
          flow (g/hr): H2O  1.8e+06
          WasteStream-specific properties:
           pH         : 7.0
+         Component concentrations (mg/L):
+          H2O          1012485.4
         >>> ws.price
         8.0
         '''
@@ -284,7 +295,7 @@ class WasteStream(SanStream):
 
 
     def show(self, T='K', P='Pa', flow='g/hr', composition=False, N=15,
-             stream_info=True, details=True):
+             stream_info=True, details=True, concentrations='mg/L'):
         '''
         Print information related to this :class:`WasteStream`.
 
@@ -319,13 +330,13 @@ class WasteStream(SanStream):
             T_units = T or display_units.T
             P_units = P or display_units.P
             info += self._info_phaseTP(self.phase, T_units, P_units)
-        info += self._wastestream_info(details=details)
+        info += self._wastestream_info(details=details, concentrations=concentrations, N=N)
         print(info)
 
     _ipython_display_ = show
 
 
-    def _wastestream_info(self, details=True):
+    def _wastestream_info(self, details=True, concentrations=None, N=15):
         _ws_info = ' WasteStream-specific properties:'
         # Wastewater-related properties are not relevant for gas or solids
         if self.phase != 'l':
@@ -349,9 +360,33 @@ class WasteStream(SanStream):
                 # _ws_info += int(bool(self.charge))*f'  charge     : {self.charge:.1f} mmol/L\n'
             else:
                 _ws_info += '  ...\n'
-
+            _ws_info += self._concentration_info(unit=concentrations, N=N)
         return _ws_info
 
+    def _concentration_info(self, unit='mg/L', N=15):
+        if not isinstance(unit, str): return ''
+        else:
+            C_arr = self.get_mass_concentration(unit=unit)
+            N_ID = sum(C_arr > 0)
+            too_many_components = N_ID > N
+            N_max =  min(N_ID, N)
+            IDs = self.components.IDs
+            lengths = [len(ID) for ID in IDs]
+            maxlen = max(lengths) + 2
+            line = f' Component concentrations ({unit}):\n'
+            n = 0
+            for i in range(len(IDs)):
+                if n == N_max: break
+                if C_arr[i] > 0:
+                    n += 1
+                    spaces = ' ' * (maxlen - lengths[i])
+                    line += '  ' + IDs[i] + spaces + f'{C_arr[i]:.1f}\n'
+            if too_many_components:
+                line += '  ...\n'
+            line = line.rstrip('\n')
+            return line
+
+
     @property
     def ratios(self):
         '''
@@ -659,6 +694,7 @@ class WasteStream(SanStream):
                 value = getattr(other, slot)
                 setattr(self, slot, value)
 
+
     def mix_from(self, others):
         '''
         Update this stream to be a mixture of other streams,
@@ -691,19 +727,20 @@ class WasteStream(SanStream):
                       H2O   1e+05
          WasteStream-specific properties:
           pH         : 7.0
+         Component concentrations (mg/L):
+          S_O2         303021.4
+          H2O          303021.4
         '''
-
         others = [s for s in others if not 'Missing' in type(s).__name__]
         Stream.mix_from(self, others)
 
         for slot in _ws_specific_slots:
-            if not hasattr(self, slot):
+            if not hasattr(self, slot) or slot=='_stream_impact_item':
                 continue
             #!!! This need reviewing, might not be good to calculate some
             # attributes like pH
             try:
-                tot = sum(float(getattr(i, slot))*i.F_vol for i in others
-                          if hasattr(i, slot))
+                tot = sum(to_float(i, slot)*i.F_vol for i in others if hasattr(i, slot))
             except: continue
 
             if tot == 0.:
@@ -725,7 +762,6 @@ class WasteStream(SanStream):
         -------
         TDS : float
             In mg/L.
-
         '''
         TDS = self.composite('solids', particle_size='s')
         if include_colloidal:
@@ -745,7 +781,6 @@ class WasteStream(SanStream):
         -------
         TSS : float
             In mg/L.
-
         '''
         TSS = self.composite('solids', particle_size='x')
         if include_colloidal:
@@ -763,6 +798,83 @@ class WasteStream(SanStream):
         '''[float] Inorganic/involatile suspended solids, in mg/L.'''
         return self.composite('solids', particle_size='x', volatile=False)
 
+
+    def get_mass_concentration(self, unit='g/m3', IDs=None):
+        '''
+        Get mass concentrations in given unit.
+
+        Parameters
+        ----------
+        unit : str, optional
+            Unit of measure. The default is 'g/m3'.
+        IDs : Iterable[str], optional
+            IDs of components. When not specified, returns mass concentrations of
+            all components in thermo.
+
+        '''
+        F_vol = self.F_vol
+        if not F_vol: raise RuntimeError(f'{repr(self)} is empty')
+        if not IDs: IDs = self.components.IDs
+        C = self.imass[IDs]/F_vol*1e3      # in mg/L
+        return C*conc_unit.conversion_factor(unit)
+
+
+    def set_flow_by_concentration(self, flow_tot, concentrations, units,
+                                  bulk_liquid_ID='H2O', atol=1e-5, maxiter=50):
+        '''
+        Set the mass flows of the WasteStream by specifying total volumetric flow and
+        concentrations as well as identifying the component that constitutes the bulk liquid.
+
+        Parameters
+        ----------
+        flow_tot : float
+            Total volumetric flow of the WasteStream.
+        concentrations : dict[str, float]
+            Concentrations of components.
+        units : iterable[str]
+            The first indicates the unit for the input total flow, the second
+            indicates the unit for the input concentrations.
+        bulk_liquid_ID : str, optional
+            ID of the Component that constitutes the bulk liquid, e.g., the solvent.
+            The default is 'H2O'.
+        atol : float, optional
+            The absoute tolerance of error in estimated WasteStream density.
+            The default is 1e-5 kg/L.
+        maxiter : int, optional
+            The maximum number of iterations to estimate the flow of the bulk-liquid
+            component and overall density of the WasteStream. The default is 50.
+
+
+        '''
+        if flow_tot == 0: raise RuntimeError(f'{repr(self)} is empty')
+        if bulk_liquid_ID in concentrations.keys():
+            C_h2o = concentrations.pop(bulk_liquid_ID)
+            warn(f'ignored concentration specified for {bulk_liquid_ID}:{C_h2o}')
+
+        self.empty()
+        f = conc_unit.conversion_factor(units[1])
+        Q_tot = flow_tot / vol_unit.conversion_factor(units[0])   # converted to L/hr
+        C_arr = np.array(list(concentrations.values()))
+        IDs = concentrations.keys()
+        M_arr = C_arr/f*Q_tot*1e-6       # kg/hr
+        dwt = M_arr.sum()                # dry weight
+        self.set_flow(M_arr, 'kg/hr', tuple(IDs))
+
+        den = self.components[bulk_liquid_ID].rho(phase=self.phase, T=self.T, P=self.P)*1e-3  # bulk liquid density in [kg/L]
+        i = 0
+        while True:
+            i += 1
+            den0 = den
+            M_tot = den0 * Q_tot
+            M_h2o = M_tot - dwt
+            self.set_flow(M_h2o, 'kg/hr', bulk_liquid_ID)
+            den = M_tot / self.get_total_flow('L/hr')
+            if abs(den0 - den) <= atol: break
+            if i > maxiter:
+                raise RuntimeError(f'{bulk_liquid_ID} mass flow calculation failed '
+                                   f'to converge within {maxiter} iterations.')
+
+
     @classmethod
     def codstates_inf_model(cls, ID, flow_tot=0., units = ('L/hr', 'mg/L'),
                             phase='l', T=298.15, P=101325., price=0., thermo=None,
@@ -904,31 +1016,7 @@ class WasteStream(SanStream):
         set_thermo(cmps)
 
         #************ convert concentrations to flow rates *************
-        flow_tot /= vol_unit.conversion_factor(units[0])
-        factor = conc_unit.conversion_factor(units[1])
-
-        cmp_dct = {k:v/factor*flow_tot*1e-6 for k,v in cmp_dct.items()}       # [mg/L]*[L/hr]*1e-6[kg/mg] = [kg/hr]
-        dwt = sum(cmp_dct.values())         # dry weight
-
-        den = 1
-        i = 0
-        while True:
-            den0 = den
-            cmp_dct['H2O'] = flow_tot*den0 - dwt
-
-            #---------- Yalin's comments ----------
-            # This is to avoid BioSTEAM showing the warning that this ID exists
-            # in the registry
-            #!!! But maybe there's a better way to deal with this?
-            # Also this appears in all of the four models, consider making this into a function
-            temp = cls(ID=ID+str(i), phase=phase, T=T, P=P, units='kg/hr', price=price,
-                      thermo=thermo, pH=pH, SAlk=SAlk, **cmp_dct)
-            den = flow_tot*den0/(temp.F_vol*1e3)
-            i += 1
-            if abs(den-den0) <= 1e-3: break
-            if i > 50: raise ValueError('Density calculation failed to converge within 50 iterations.')
-
-        new.mass = temp.mass
+        new.set_flow_by_concentration(flow_tot, cmp_dct, units)
         new.ratios = r
 
         return new
@@ -1081,25 +1169,7 @@ class WasteStream(SanStream):
         set_thermo(cmps)
 
         #************ convert concentrations to flow rates *************
-        flow_tot /= vol_unit.conversion_factor(units[0])
-        factor = conc_unit.conversion_factor(units[1])
-
-        cmp_dct = {k:v/factor*flow_tot*1e-6 for k,v in cmp_dct.items()}       # [mg/L]*[L/hr]*1e-6[kg/mg] = [kg/hr]
-        dwt = sum(cmp_dct.values())
-
-        den = 1
-        i = 0
-        while True:
-            den0 = den
-            cmp_dct['H2O'] = flow_tot*den0 - dwt
-            temp = cls(ID=ID+str(i), phase=phase, T=T, P=P, units='kg/hr', price=price,
-                      thermo=thermo, pH=pH, SAlk=SAlk, **cmp_dct)
-            den = flow_tot*den0/(temp.F_vol*1e3)
-            i += 1
-            if abs(den-den0) <= 1e-3: break
-            if i > 50: raise ValueError('Density calculation failed to converge within 50 iterations.')
-
-        new.mass = temp.mass
+        new.set_flow_by_concentration(flow_tot, cmp_dct, units)
         new.ratios = r
 
         return new
@@ -1253,25 +1323,7 @@ class WasteStream(SanStream):
         set_thermo(cmps)
 
         #************ convert concentrations to flow rates *************
-        flow_tot /= vol_unit.conversion_factor(units[0])
-        factor = conc_unit.conversion_factor(units[1])
-
-        cmp_dct = {k:v/factor*flow_tot*1e-6 for k,v in cmp_dct.items()}       # [mg/L]*[L/hr]*1e-6[kg/mg] = [kg/hr]
-        dwt = sum(cmp_dct.values())
-
-        den = 1
-        i = 0
-        while True:
-            den0 = den
-            cmp_dct['H2O'] = flow_tot*den0 - dwt
-            temp = cls(ID=ID+str(i), phase=phase, T=T, P=P, units='kg/hr', price=price,
-                      thermo=thermo, pH=pH, SAlk=SAlk, **cmp_dct)
-            den = flow_tot*den0/(temp.F_vol*1e3)
-            i += 1
-            if abs(den-den0) <= 1e-3: break
-            if i > 50: raise ValueError('Density calculation failed to converge within 50 iterations.')
-
-        new.mass = temp.mass
+        new.set_flow_by_concentration(flow_tot, cmp_dct, units)
         new.ratios = r
 
         return new
@@ -1420,25 +1472,7 @@ class WasteStream(SanStream):
         set_thermo(cmps)
 
         #************ convert concentrations to flow rates *************
-        flow_tot /= vol_unit.conversion_factor(units[0])
-        factor = conc_unit.conversion_factor(units[1])
-
-        cmp_dct = {k:v/factor*flow_tot*1e-6 for k,v in cmp_dct.items()}       # [mg/L]*[L/hr]*1e-6[kg/mg] = [kg/hr]
-        dwt = sum(cmp_dct.values())
-
-        den = 1
-        i = 0
-        while True:
-            den0 = den
-            cmp_dct['H2O'] = flow_tot*den0 - dwt
-            temp = cls(ID=ID+str(i), phase=phase, T=T, P=P, units='kg/hr', price=price,
-                      thermo=thermo, pH=pH, SAlk=SAlk, **cmp_dct)
-            den = flow_tot*den0/(temp.F_vol*1e3)
-            i += 1
-            if abs(den-den0) <= 1e-3: break
-            if i > 50: raise ValueError('Density calculation failed to converge within 50 iterations.')
-
-        new.mass = temp.mass
+        new.set_flow_by_concentration(flow_tot, cmp_dct, units)
         new.ratios = r
 
         return new
