@@ -16,10 +16,12 @@ from ._anaerobic_baffled_reactor import *
 from ._anaerobic_digestion import *
 from ._biogas_combustion import *
 from ._bst_units import *
+from ._clarifier import *
 from ._component_splitter import *
 from ._crop_application import *
 from ._decay import *
 from ._drying_bed import *
+from ._electrochemical_cell import *
 from ._excretion import *
 from ._lagoon import *
 from ._liquid_treatment_bed import *
@@ -27,6 +29,7 @@ from ._lumped_cost import *
 from ._pit_latrine import *
 from ._sedimentation_tank import *
 from ._sludge_separator import *
+from ._suspended_growth_bioreactor import *
 from ._toilet import *
 from ._trucking import *
 from ._uddt import *
@@ -37,10 +40,12 @@ from . import (
     _anaerobic_digestion,
     _biogas_combustion,
     _bst_units,
+    _clarifier,
     _component_splitter,
     _crop_application,
     _decay,
     _drying_bed,
+    _electrochemical_cell,
     _excretion,
     _lagoon,
     _liquid_treatment_bed,
@@ -48,6 +53,7 @@ from . import (
     _pit_latrine,
     _sedimentation_tank,
     _sludge_separator,
+    _suspended_growth_bioreactor,
     _toilet,
     _trucking,
     _uddt,
@@ -59,10 +65,12 @@ __all__ = (
     *_anaerobic_digestion.__all__,
     *_biogas_combustion.__all__,
     *_bst_units.__all__,
+    *_clarifier.__all__,
     *_component_splitter.__all__,
     *_crop_application.__all__,
     *_decay.__all__,
     *_drying_bed.__all__,
+    *_electrochemical_cell.__all__,
     *_excretion.__all__,
     *_lagoon.__all__,
     *_liquid_treatment_bed.__all__,
@@ -70,7 +78,8 @@ __all__ = (
     *_pit_latrine.__all__,
     *_sedimentation_tank.__all__,
     *_sludge_separator.__all__,
+    *_suspended_growth_bioreactor.__all__,
     *_toilet.__all__,
     *_trucking.__all__,
     *_uddt.__all__,
-           )
\ No newline at end of file
+           )
