@@ -30,23 +30,26 @@ class CropApplication(SanUnit):
         If material loss occurs during application.
     loss_ratio : float or dict
         Fractions of material losses during application (if `if_materiloass` is True).
-        
+
+    Examples
+    --------
+    `bwaise systems <https://github.com/QSD-Group/EXPOsan/blob/main/exposan/bwaise/systems.py>`_
+
     References
     ----------
     .. [1] Trimmer et al., Navigating Multidimensional Social–Ecological System
         Trade-Offs across Sanitation Alternatives in an Urban Informal Settlement.
         Environ. Sci. Technol. 2020, 54 (19), 12641–12653.
-        https://doi.org/10.1021/acs.est.0c03296. 
- 
+        https://doi.org/10.1021/acs.est.0c03296.
     '''
-    
+
     def __init__(self, ID='', ins=None, outs=(), thermo=None, init_with='WasteStream',
                  if_material_loss=True, loss_ratio=0.02):
 
         SanUnit.__init__(self, ID, ins, outs, thermo, init_with)
         self.if_material_loss = if_material_loss
         self.loss_ratio = loss_ratio
-    
+
     _N_ins = 1
     _N_outs = 2
 
@@ -71,13 +74,13 @@ class CropApplication(SanUnit):
         [float] or [dict] Fractions of material losses during application.
         If a single number is provided, then it is assumed that losses of
         all Components in the WasteStream are the same.
-        
+
         .. note::
-            
+
             Set state variable values (e.g., COD) will be retained if the loss
             ratio is a single number (treated like the loss stream is split
             from the original stream), but not when the ratio is a dict.
-            
+
         '''
         return self._loss_ratio
     @loss_ratio.setter
@@ -89,28 +92,9 @@ class CropApplication(SanUnit):
             try:
                 self._loss_ratio = float(i)
                 self._loss_ratio_type = 'float'
-            except:
+            except TypeError:
                 if isinstance(i, dict):
                     self._loss_ratio = i
                     self._loss_ratio_type = 'dict'
                 else:
-                    raise TypeError(f'Only float or dict allowed, not {type(i).__name__}.')
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+                    raise TypeError(f'Only float or dict allowed, not {type(i).__name__}.')
\ No newline at end of file
