@@ -28,21 +28,24 @@ class Excretion(SanUnit):
     '''
     Estimation of N, P, K, and COD in urine and feces based on dietary intake
     for one person based on Trimmer et al. [1]_
-    
+
+    Examples
+    --------
+    `bwaise systems <https://github.com/QSD-Group/EXPOsan/blob/main/exposan/bwaise/systems.py>`_
+
     References
     ----------
     .. [1] Trimmer et al., Navigating Multidimensional Social–Ecological System
         Trade-Offs across Sanitation Alternatives in an Urban Informal Settlement.
         Environ. Sci. Technol. 2020, 54 (19), 12641–12653.
         https://doi.org/10.1021/acs.est.0c03296.
-    
     '''
-    
+
     _N_ins = 0
     _N_outs = 2
-    
+
     def __init__(self, ID='', ins=None, outs=(), thermo=None, init_with='WasteStream',
-                 **kwargs):                
+                 **kwargs):
         SanUnit.__init__(self, ID, ins, outs, thermo, init_with)
         data = load_data(path=data_path)
         for para in data.index:
@@ -72,10 +75,10 @@ class Excretion(SanUnit):
         ur.imass['Ca'] = self.Ca_ur / factor
         ur.imass['H2O'] = self.ur_moi * ur_exc
         ur.imass['OtherSS'] = ur_exc - ur.F_mass
-        
+
         fec_exc = self.fec_exc / factor
         fec_N = (1-self.N_ur)/self.N_ur * ur_N
-        fec.imass['NH3'] = fec_N * self.N_fec_NH3   
+        fec.imass['NH3'] = fec_N * self.N_fec_NH3
         fec.imass['NonNH3'] = fec_N - fec.imass['NH3']
         fec.imass['P'] = (1-self.P_ur)/self.P_ur * ur.imass['P']
         fec.imass['K'] = (1-self.K_ur)/self.K_ur * ur.imass['K']
@@ -83,7 +86,7 @@ class Excretion(SanUnit):
         fec.imass['Ca'] = self.Ca_fec / factor
         fec.imass['H2O'] = self.fec_moi * fec_exc
         fec.imass['OtherSS'] = fec_exc - fec.F_mass
-        
+
         # 14 kJ/g COD, the average lower heating value of excreta
         tot_COD = e_cal*self.e_exc*4.184/14/1e3 # in kg COD/hr
         ur._COD = tot_COD*(1-self.e_fec) / (ur.F_vol/1e3) # in mg/L
@@ -95,15 +98,15 @@ class Excretion(SanUnit):
         return self._e_cal
     @e_cal.setter
     def e_cal(self, i):
-        self._e_cal = float(i)
-    
+        self._e_cal = i
+
     @property
     def p_veg(self):
         '''[float] Vegetal protein intake, [g/cap/d].'''
         return self._p_veg
     @p_veg.setter
     def p_veg(self, i):
-        self._p_veg = float(i)
+        self._p_veg = i
 
     @property
     def p_anim(self):
@@ -111,7 +114,7 @@ class Excretion(SanUnit):
         return self._p_anim
     @p_anim.setter
     def p_anim(self, i):
-        self._p_anim = float(i)
+        self._p_anim = i
 
     @property
     def N_prot(self):
@@ -119,7 +122,7 @@ class Excretion(SanUnit):
         return self._N_prot
     @N_prot.setter
     def N_prot(self, i):
-        self._N_prot = float(i)
+        self._N_prot = i
 
     @property
     def P_prot_v(self):
@@ -127,7 +130,7 @@ class Excretion(SanUnit):
         return self._P_prot_v
     @P_prot_v.setter
     def P_prot_v(self, i):
-        self._P_prot_v = float(i)
+        self._P_prot_v = i
 
     @property
     def P_prot_a(self):
@@ -135,7 +138,7 @@ class Excretion(SanUnit):
         return self._P_prot_a
     @P_prot_a.setter
     def P_prot_a(self, i):
-        self._P_prot_a = float(i)
+        self._P_prot_a = i
 
     @property
     def K_cal(self):
@@ -143,7 +146,7 @@ class Excretion(SanUnit):
         return self._K_cal
     @K_cal.setter
     def K_cal(self, i):
-        self._K_cal = float(i)
+        self._K_cal = i
 
     @property
     def N_exc(self):
@@ -151,7 +154,7 @@ class Excretion(SanUnit):
         return self._N_exc
     @N_exc.setter
     def N_exc(self, i):
-        self._N_exc = float(i)
+        self._N_exc = i
 
     @property
     def P_exc(self):
@@ -159,7 +162,7 @@ class Excretion(SanUnit):
         return self._P_exc
     @P_exc.setter
     def P_exc(self, i):
-        self._P_exc = float(i)
+        self._P_exc = i
 
     @property
     def K_exc(self):
@@ -167,7 +170,7 @@ class Excretion(SanUnit):
         return self._K_exc
     @K_exc.setter
     def K_exc(self, i):
-        self._K_exc = float(i)
+        self._K_exc = i
 
     @property
     def e_exc(self):
@@ -175,7 +178,7 @@ class Excretion(SanUnit):
         return self._e_exc
     @e_exc.setter
     def e_exc(self, i):
-        self._e_exc = float(i)
+        self._e_exc = i
 
     @property
     def N_ur(self):
@@ -183,7 +186,7 @@ class Excretion(SanUnit):
         return self._N_ur
     @N_ur.setter
     def N_ur(self, i):
-        self._N_ur = float(i)
+        self._N_ur = i
 
     @property
     def P_ur(self):
@@ -191,7 +194,7 @@ class Excretion(SanUnit):
         return self._P_ur
     @P_ur.setter
     def P_ur(self, i):
-        self._P_ur = float(i)
+        self._P_ur = i
 
     @property
     def K_ur(self):
@@ -199,7 +202,7 @@ class Excretion(SanUnit):
         return self._K_ur
     @K_ur.setter
     def K_ur(self, i):
-        self._K_ur = float(i)
+        self._K_ur = i
 
     @property
     def e_fec(self):
@@ -207,7 +210,7 @@ class Excretion(SanUnit):
         return self._e_fec
     @e_fec.setter
     def e_fec(self, i):
-        self._e_fec = float(i)
+        self._e_fec = i
 
     @property
     def N_ur_NH3(self):
@@ -215,7 +218,7 @@ class Excretion(SanUnit):
         return self._N_ur_NH3
     @N_ur_NH3.setter
     def N_ur_NH3(self, i):
-        self._N_ur_NH3 = float(i)
+        self._N_ur_NH3 = i
 
     @property
     def N_fec_NH3(self):
@@ -223,7 +226,7 @@ class Excretion(SanUnit):
         return self._N_fec_NH3
     @N_fec_NH3.setter
     def N_fec_NH3(self, i):
-        self._N_fec_NH3 = float(i)
+        self._N_fec_NH3 = i
 
     @property
     def ur_exc(self):
@@ -231,7 +234,7 @@ class Excretion(SanUnit):
         return self._ur_exc
     @ur_exc.setter
     def ur_exc(self, i):
-        self._ur_exc = float(i)
+        self._ur_exc = i
 
     @property
     def fec_exc(self):
@@ -239,7 +242,7 @@ class Excretion(SanUnit):
         return self._fec_exc
     @fec_exc.setter
     def fec_exc(self, i):
-        self._fec_exc = float(i)
+        self._fec_exc = i
 
     @property
     def ur_moi(self):
@@ -247,7 +250,7 @@ class Excretion(SanUnit):
         return self._ur_moi
     @ur_moi.setter
     def ur_moi(self, i):
-        self._ur_moi = float(i)
+        self._ur_moi = i
 
     @property
     def fec_moi(self):
@@ -255,7 +258,7 @@ class Excretion(SanUnit):
         return self._fec_moi
     @fec_moi.setter
     def fec_moi(self, i):
-        self._fec_moi = float(i)
+        self._fec_moi = i
 
     @property
     def Mg_ur(self):
@@ -263,7 +266,7 @@ class Excretion(SanUnit):
         return self._Mg_ur
     @Mg_ur.setter
     def Mg_ur(self, i):
-        self._Mg_ur = float(i)
+        self._Mg_ur = i
 
     @property
     def Mg_fec(self):
@@ -271,7 +274,7 @@ class Excretion(SanUnit):
         return self._Mg_fec
     @Mg_fec.setter
     def Mg_fec(self, i):
-        self._Mg_fec = float(i)
+        self._Mg_fec = i
 
     @property
     def Ca_ur(self):
@@ -279,7 +282,7 @@ class Excretion(SanUnit):
         return self._Ca_ur
     @Ca_ur.setter
     def Ca_ur(self, i):
-        self._Ca_ur = float(i)
+        self._Ca_ur = i
 
     @property
     def Ca_fec(self):
@@ -287,6 +290,4 @@ class Excretion(SanUnit):
         return self._Ca_fec
     @Ca_fec.setter
     def Ca_fec(self, i):
-        self._Ca_fec = float(i)
-
-
+        self._Ca_fec = i
\ No newline at end of file
